@@ -1,10 +1,10 @@
-__version__ = "0.2.10"
+__version__ = "0.2.11"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.2.10)'
+__git_branch__ = '(detached from v0.2.11)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'd29c0f6cc195280aeef055fcf404b39dabaace1c'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '12977113302dbeecf0087a86ca48072de5883840'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
